<template>
  <el-dialog :close-on-click-modal="false" :visible.sync="visible">
    <!--<span>{{dynamicTitle}}</span>-->
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="140px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="原因码编号" prop="stockCodeNo">
            <el-input
              v-model="dataForm.stockCodeNo"
              placeholder="原因码编号"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="出入库原因码描述" prop="stockCodeName">
            <el-input
              v-model="dataForm.stockCodeName"
              placeholder="出入库原因码描述"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="创建时间" prop="createTime">
            <el-date-picker
              readonly
              style="width: 100%"
              v-model="moment"
              type="datetime"
              placeholder="选择日期时间"
              value-format="yyyy-MM-dd HH:mm:ss"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="备注" prop="stockCodeRemark">
            <el-input
              v-model="dataForm.stockCodeRemark"
              placeholder="备注"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="原因码类型" prop="stockCodeType">
            <el-radio-group v-model="dataForm.stockCodeType">
              <el-radio v-model="radio" :label="1">出库</el-radio>
              <el-radio v-model="radio" :label="0">入库</el-radio>
            </el-radio-group>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="启动状态" prop="stockCodeStatus">
            <el-switch
              v-model="dataForm.stockCodeStatus"
              :active-value="1"
              :inactive-value="0"
            ></el-switch>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>
<script>
import { getObj, addObj, putObj } from '@/api/warehouse/stockincode'

export default {
  data() {
    return {
      radio: '',
      moment: '',
      dynamicTitle: '',
      visible: false,
      dataForm: {
        id: 0,
        stockCodeType: '',
        stockCodeNo: '',
        stockCodeName: '',
        createTime: '',
        stockCodeStatus: '',
        stockCodeRemark: ''
      },
      dataRule: {
        stockCodeType: [
          { required: true, message: '原因码类型不能为空', trigger: 'blur' }
        ],
        stockCodeNo: [
          { required: true, message: '出入库原因码不能为空', trigger: 'blur' }
        ],
        stockCodeName: [
          {
            required: true,
            message: '出入库原因码描述不能为空',
            trigger: 'blur'
          }
        ],
        stockCodeStatus: [
          { required: true, message: '启动状态不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },

  methods: {
    getDataTime() {
      this.moment = new Date()
    },
    init(id) {
      this.getDataTime()
      this.dataForm.id = id || 0
      this.dataForm.stockCodeStatus = 1
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
            this.radio = this.dataForm.stockCodeType.toString()
            this.moment = this.dataForm.createTime
            this.dynamicTitle =
              this.dataForm.stockCodeNo + this.dataForm.stockCodeNo
          })
        } else {
          this.dynamicTitle = '新增'
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
